sqltriples.Query.Disjunction

Package sqltriples :: Module Query :: Class Disjunction |
[show private | hide private]
[frames | no frames]

## Class Disjunction

    CombinedResults --+
                      |
                     Disjunction

Known Subclasses:
  `DisjunctionOfObjects`, `DisjunctionOfPredicates`, `DisjunctionOfSubjects`, `DisjunctionOfTriples`, `DisjunctionOfTuples`

Method Summary
Inherited from CombinedResults
| ``get_query`(self, index)`
| ``get_subquery`(self, parent_columns, parent_index, index, match_first, match_parent, match_child)`

Class Variable Summary
`int` | `in_parentheses` = 1
`str` | `operator` = `'or'`

Class Variable Details

    ### in_parentheses Type: `int` Value:
        1

    ### operator Type: `str` Value:
        'or'

Generated by Epydoc 2.1 on Fri Jan 12 00:04:34 2007 | http://epydoc.sf.net